==> vuepress-plugin-full-text-search-page-0.1.3.tgz: package/lib/index.js <==
import "./chunk-MIL7QFH3.js";

// src/index.ts
import { createPage } from "@vuepress/core";
import { path } from "@vuepress/utils";
import { fileURLToPath } from "url";

// src/prepare-search-index.ts
import { Parser } from "htmlparser2";
var HMR_CODE = `
if (import.meta.webpackHot) {
  import.meta.webpackHot.accept()
  if (__VUE_HMR_RUNTIME__[UPD_NAME]) {
    __VUE_HMR_RUNTIME__[UPD_NAME](searchIndex)
  }
}

if (import.meta.hot) {
  import.meta.hot.accept(({ searchIndex }) => {
    if (__VUE_HMR_RUNTIME__[UPD_NAME]) {
      __VUE_HMR_RUNTIME__[UPD_NAME](searchIndex)
    }
  })
}
`;
async function prepareSearchIndex({
  app
}) {
  const searchIndex = [];
  for (const page of app.pages) {
    searchIndex.push({
      path: page.path,
      title: page.title,
      pathLocale: page.pathLocale,
      contents: extractPageContents(page)
    });
  }
  let content = `
export const searchIndex = ${JSON.stringify(searchIndex, null, 2)}
export const UPD_NAME = 'update-vuepress2-plugin-full-text-search-search-index'
`;
  if (app.env.isDev) {
    content += HMR_CODE;
  }
  return app.writeTemp("internal/vuepress2-plugin-full-text-search-search-index.js", content);
}
function extractPageContents(page) {
  const results = [];
  const slugs = /* @__PURE__ */ new Map();
  const headers = [...page.headers];
  while (headers.length) {
    const h = headers.shift();
    slugs.set(h.slug, h.title);
    headers.push(...h.children);
  }
  let ignoreElement = 0;
  let withinHeader = 0;
  let scope = {
    header: "",
    slug: "",
    content: ""
  };
  results.push(scope);
  const parser = new Parser({
    ontext(text) {
      if (ignoreElement) {
        return;
      }
      const prop = withinHeader ? "header" : "content";
      scope[prop] += text;
    },
    onopentag(name, attribute) {
      if (ignoreElement || name === "script" || name === "style" || name === "div" && attribute.class === "line-numbers") {
        ignoreElement++;
        return;
      }
      if (withinHeader) {
        withinHeader++;
        return;
      }
      if (!/^h\d$/u.test(name)) {
        return;
      }
      const id = attribute.id;
      const title = slugs.get(id);
      if (title) {
        scope = {
          header: title,
          slug: id,
          content: ""
        };
        results.push(scope);
        ignoreElement++;
      } else {
        scope = {
          header: "",
          slug: id,
          content: ""
        };
        results.push(scope);
        withinHeader++;
      }
    },
    onclosetag() {
      if (ignoreElement) {
        ignoreElement--;
        return;
      }
      if (withinHeader) {
        withinHeader--;
      }
    }
  });
  parser.parseComplete(page.contentRendered);
  return results.map((p) => {
    p.header = p.header.replace(/\s{2,}/g, " ").replace(/^#/g, "").trim();
    p.content = p.content.replace(/\s{2,}/g, " ").trim();
    return p;
  }).filter((p) => p.content || p.header);
}

// src/index.ts
import * as chokidar from "chokidar";
var filename = fileURLToPath(import.meta.url);
var dirname = path.dirname(filename);
var fullTextSearchPlugin = fullTextSearchPluginFunction;
var src_default = fullTextSearchPlugin;
function fullTextSearchPluginFunction(_options) {
  const searchRoute = _options.searchPageName ? _options.searchPageName.toLowerCase() : "search";
  return {
    name: "vuepress2-plugin-full-text-search",
    clientAppEnhanceFiles: path.resolve(dirname, "./client/clientAppEnhance.js"),
    onPrepared(app) {
      app.writeTemp("internal/vuepress2-plugin-full-text-search-add-page.js", `
                export const addSearchPage = ${_options.addSearchPage}
                export const searchRoute = '${searchRoute}'
                `);
      prepareSearchIndex({ app });
    },
    async onInitialized(app) {
      if (_options.addSearchPage) {
        const locales = Object.keys(app.siteData.locales);
        const pages = await Promise.all(locales.map((locale) => createPage(app, {
          path: `${locale}${searchRoute}`,
          content: "<SearchPage />",
          frontmatter: {
            title: searchRoute.replace(/^\w/, (c) => c.toUpperCase())
          }
        })));
        pages.map((page) => app.pages.push(page));
      }
    },
    onWatched: (app, watchers) => {
      const searchIndexWatcher = chokidar.watch("internal/pageData/*", {
        cwd: app.dir.temp(),
        ignoreInitial: true
      });
      searchIndexWatcher.on("add", () => {
        prepareSearchIndex({ app });
      });
      searchIndexWatcher.on("change", () => {
        prepareSearchIndex({ app });
      });
      searchIndexWatcher.on("unlink", () => {
        prepareSearchIndex({ app });
      });
      watchers.push(searchIndexWatcher);
    }
  };
}
export {
  src_default as default,
  fullTextSearchPlugin
};

==> vuepress-plugin-full-text-search-page-0.1.5.tgz: package/lib/index.js <==
import "./chunk-MIL7QFH3.js";

// src/index.ts
import { createPage } from "@vuepress/core";
import { path } from "@vuepress/utils";
import { fileURLToPath } from "url";

// src/prepare-search-index.ts
import { Parser } from "htmlparser2";
var HMR_CODE = `
if (import.meta.webpackHot) {
  import.meta.webpackHot.accept()
  if (__VUE_HMR_RUNTIME__[UPD_NAME]) {
    __VUE_HMR_RUNTIME__[UPD_NAME](searchIndex)
  }
}

if (import.meta.hot) {
  import.meta.hot.accept(({ searchIndex }) => {
    if (__VUE_HMR_RUNTIME__[UPD_NAME]) {
      __VUE_HMR_RUNTIME__[UPD_NAME](searchIndex)
    }
  })
}
`;
async function prepareSearchIndex({
  app
}) {
  const searchIndex = [];
  for (const page of app.pages) {
    searchIndex.push({
      path: page.path,
      title: page.title,
      pathLocale: page.pathLocale,
      contents: extractPageContents(page)
    });
  }
  let content = `
export const searchIndex = ${JSON.stringify(searchIndex, null, 2)}
export const UPD_NAME = 'update-vuepress2-plugin-full-text-search-search-index'
`;
  if (app.env.isDev) {
    content += HMR_CODE;
  }
  return app.writeTemp("internal/vuepress2-plugin-full-text-search-search-index.js", content);
}
function extractPageContents(page) {
  const results = [];
  const slugs = /* @__PURE__ */ new Map();
  const headers = [...page.headers];
  while (headers.length) {
    const h = headers.shift();
    slugs.set(h.slug, h.title);
    headers.push(...h.children);
  }
  let ignoreElement = 0;
  let withinHeader = 0;
  let scope = {
    header: "",
    slug: "",
    content: ""
  };
  results.push(scope);
  const parser = new Parser({
    ontext(text) {
      if (ignoreElement) {
        return;
      }
      const prop = withinHeader ? "header" : "content";
      scope[prop] += text;
    },
    onopentag(name, attribute) {
      if (ignoreElement || name === "script" || name === "style" || name === "div" && attribute.class === "line-numbers") {
        ignoreElement++;
        return;
      }
      if (withinHeader) {
        withinHeader++;
        return;
      }
      if (!/^h\d$/u.test(name)) {
        return;
      }
      const id = attribute.id;
      const title = slugs.get(id);
      if (title) {
        scope = {
          header: title,
          slug: id,
          content: ""
        };
        results.push(scope);
        ignoreElement++;
      } else {
        scope = {
          header: "",
          slug: id,
          content: ""
        };
        results.push(scope);
        withinHeader++;
      }
    },
    onclosetag() {
      if (ignoreElement) {
        ignoreElement--;
        return;
      }
      if (withinHeader) {
        withinHeader--;
      }
    }
  });
  parser.parseComplete(page.contentRendered);
  return results.map((p) => {
    p.header = p.header.replace(/\s{2,}/g, " ").replace(/^#/g, "").trim();
    p.content = p.content.replace(/\s{2,}/g, " ").trim();
    return p;
  }).filter((p) => p.content || p.header);
}

// src/index.ts
import * as chokidar from "chokidar";
var filename = fileURLToPath(import.meta.url);
var dirname = path.dirname(filename);
var fullTextSearchPlugin = fullTextSearchPluginFunction;
var src_default = fullTextSearchPlugin;
function fullTextSearchPluginFunction(_options) {
  const searchRoute = _options.searchPageName ? _options.searchPageName.toLowerCase() : "search";
  return {
    name: "vuepress2-plugin-full-text-search",
    clientAppEnhanceFiles: path.resolve(dirname, "./client/clientAppEnhance.js"),
    onPrepared(app) {
      app.writeTemp("internal/vuepress2-plugin-full-text-search-add-page.js", `
                export const addSearchPage = ${_options.addSearchPage}
                export const searchRoute = '${searchRoute}'
                `);
      prepareSearchIndex({ app });
    },
    async onInitialized(app) {
      if (_options.addSearchPage) {
        const locales = Object.keys(app.siteData.locales).length > 0 ? Object.keys(app.siteData.locales) : ["/"];
        const pages = await Promise.all(locales.map((locale) => createPage(app, {
          path: `${locale}${searchRoute}`,
          content: "<SearchPage />",
          frontmatter: {
            title: searchRoute.replace(/^\w/, (c) => c.toUpperCase())
          }
        })));
        pages.map((page) => app.pages.push(page));
      }
    },
    onWatched: (app, watchers) => {
      const searchIndexWatcher = chokidar.watch("internal/pageData/*", {
        cwd: app.dir.temp(),
        ignoreInitial: true
      });
      searchIndexWatcher.on("add", () => {
        prepareSearchIndex({ app });
      });
      searchIndexWatcher.on("change", () => {
        prepareSearchIndex({ app });
      });
      searchIndexWatcher.on("unlink", () => {
        prepareSearchIndex({ app });
      });
      watchers.push(searchIndexWatcher);
    }
  };
}
export {
  src_default as default,
  fullTextSearchPlugin
};
